@@ -4,7 +4,7 @@ import uuid
 import pika
 from pika.exceptions import AMQPConnectionError, ProbableAuthenticationError
 
-from exceptions import ProcedureExecutionException
+from FLF.exceptions import ProcedureExecutionException
 
 
 class Store:
