@@ -12,14 +12,14 @@ def main():
     args = parser.parse_args()
 
     connector = RpcConnector(host=args.host, port=args.port, username=args.username, password=args.password)
+    connector.begin()
 
     file_bytes = b"hello, this is a file"
-    r1 = connector.call_procedure("addition", {"a": 22, "b": 33}, {"file": file_bytes})
-    r2 = connector.call_procedure("multiply", {"a": 33, "b": 33}, {"file": file_bytes})
-    r3 = connector.call_procedure("addition", {"a": 234, "b": 33}, {"file": file_bytes})
-    r4 = connector.call_procedure("multiply", {"a": 22, "b": 33}, {"file": file_bytes})
-
-    print(r1[0], r2[0], r3[0], r4[0], r1[1], r2[1], r3[1], r4[1])
+    print(connector.call_procedure("addition", {"a": 22, "b": 33}, {"file": file_bytes}))
+    print(connector.call_procedure("multiply", {"a": 33, "b": 33}, {"file": file_bytes}))
+    print(connector.call_procedure("addition", {"a": 234, "b": 33}, {"file": file_bytes}))
+    print(connector.call_procedure("multiply", {"a": 22, "b": 33}, {"file": file_bytes}))
+    print(connector.call_procedure("unknown4real"))
 
 
 if __name__ == "__main__":
